@@ -1,7 +1,7 @@
 from django.db import models
+from edc_constants.choices import DOCUMENT_STATUS
 
 from . import crf_status_default
-from .choices import CRF_STATUS
 from .update_crf_status_for_instance import update_crf_status_for_instance
 
 
@@ -9,7 +9,7 @@ class CrfStatusModelMixin(models.Model):
     crf_status = models.CharField(
         verbose_name="CRF status",
         max_length=25,
-        choices=CRF_STATUS,
+        choices=DOCUMENT_STATUS,
         default=crf_status_default,
         help_text="If some data is still pending, flag this CRF as incomplete",
     )
